@@ -5,7 +5,9 @@ function(x, ...)
     n.clones <- ifelse(is.null(nclones(x)), 1, nclones(x))
     if (nchain(x) > 1) {
         abin <- getOption("dclone.autoburnin")
-        rhat <- gelman.diag(x, autoburnin=abin)$mpsrf
+        rhat <- if (nvar(x) > 1) 
+            gelman.diag(x, autoburnin=abin)$mpsrf
+            else gelman.diag(x, autoburnin=abin)$psrf[,1]
     } else rhat <- NA
     rval <- c(n.clones = n.clones,
 #        n.params = nvar(x),
